==> qt-creator-2.3.1-src.zip: qt-creator-2.3.1-src/src/plugins/imageviewer/imageviewerfactory.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
** Copyright (c) 2010 Denis Mingulov.
**
** Contact: Nokia Corporation (info@qt.nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at info@qt.nokia.com.
**
**************************************************************************/

#ifndef IMAGEVIEWERFACTORY_H
#define IMAGEVIEWERFACTORY_H

#include <coreplugin/editormanager/ieditorfactory.h>
#include <coreplugin/editormanager/ieditor.h>
#include <coreplugin/ifile.h>

#include <QtCore/QScopedPointer>

namespace ImageViewer {
namespace Internal {

class ImageViewerFactory : public Core::IEditorFactory
{
    Q_OBJECT
public:
    explicit ImageViewerFactory(QObject *parent = 0);
    ~ImageViewerFactory();

    Core::IEditor *createEditor(QWidget *parent);

    QStringList mimeTypes() const;

    QString id() const;
    QString displayName() const;

    Core::IFile *open(const QString &fileName);

    void extensionsInitialized();

private:
    QScopedPointer<struct ImageViewerFactoryPrivate> d_ptr;
};

} // namespace Internal
} // namespace ImageViewer

#endif // IMAGEVIEWERFACTORY_H

==> qt-creator-2.4.1-src.zip: qt-creator-2.4.1-src/src/plugins/imageviewer/imageviewerfactory.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
** Copyright (c) 2010 Denis Mingulov.
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/

#ifndef IMAGEVIEWERFACTORY_H
#define IMAGEVIEWERFACTORY_H

#include <coreplugin/editormanager/ieditorfactory.h>
#include <coreplugin/editormanager/ieditor.h>
#include <coreplugin/ifile.h>

namespace ImageViewer {
namespace Internal {

class ImageViewerFactory : public Core::IEditorFactory
{
    Q_OBJECT
public:
    explicit ImageViewerFactory(QObject *parent = 0);
    ~ImageViewerFactory();

    Core::IEditor *createEditor(QWidget *parent);

    QStringList mimeTypes() const;
    Core::Id id() const;
    QString displayName() const;
    Core::IFile *open(const QString &fileName);

    void extensionsInitialized();

private:
    struct ImageViewerFactoryPrivate *d;
};

} // namespace Internal
} // namespace ImageViewer

#endif // IMAGEVIEWERFACTORY_H
